米朝首脳直通電話 習氏に挑むトランプ戦術の成否 （写真＝ロイター） ：日本経済新聞
Description: ６月12日の歴史的な米朝首脳会談を巡って戦っていたのは、米大統領のトランプと北朝鮮委員長の金正恩（キム・ジョンウン）ばかりではなかった。中国国家主席、習近平（シー・ジンピン）も重要な陰の参戦者だった
Keywords: 北朝鮮政府,中朝関係,米国政府,習近平,金正恩,温家宝,トランプ,蔡英文,李克強,父の日,マリーナベイ・サンズ,米朝ホットライン開設,中国,ワシントン,中国国際航空

2018年6月20日（水）
International
設定

- ご購読サポート
- チャットサポート
- ヘルプセンター
- 日経ＩＤラウンジ
- ご購読の申し込み

ログイン
お申し込み

- トップ
- 経済・政治
- ビジネス
- マーケット
- テクノロジー
- 国際・アジア
- スポーツ
- 社会
- 地域
- オピニオン
- 文化
- マネー
- ライフ

- 朝刊・夕刊
- 日経会社情報
- 人事ウオッチ
- Myニュース

## 1日 0:00更新 -

再表示
閉じる

## 1日 0:00更新 -

再表示
閉じる

## 1日 0:00更新 -

再表示
閉じる

# 米朝首脳直通電話　習氏に挑むトランプ戦術の成否
編集委員　中沢克二

  北朝鮮
  トランプ政権
  南北首脳会談
  習政権ウォッチ
  習政権
  経済
  政治
  コラム（国際・アジア）
  中国・台湾
  朝鮮半島
  北米

  （1/3ページ）
  2018/6/19 5:50
情報元
  日本経済新聞　電子版

記事保存

有料会員の方のみご利用になれます。保存した記事はスマホやタブレットでもご覧いただけます。

＞ 新規会員登録

＞ ログイン

Evernote保存

ご利用には会員登録が必要です

＞ 新規会員登録

＞ ログイン

##### 共有

##### 文字サイズ

  小javascript:void(0)javascript:void(0)
  中javascript:void(0)javascript:void(0)
  大javascript:void(0)javascript:void(0)

##### 日経の記事利用サービス

企業での記事共有や会議資料への転載・複製、注文印刷などをご希望の方は、リンク先をご覧ください。
詳しくはこちら

  保存javascript:void(0)
  共有
  その他javascript:void(0)

６月12日の歴史的な米朝首脳会談を巡って戦っていたのは、米大統領のトランプと北朝鮮委員長の金正恩（キム・ジョンウン）ばかりではなかった。中国国家主席、習近平（シー・ジンピン）も重要な陰の参戦者だった。核放棄を巡って「検証可能な」の文字がなく、米韓軍事演習の中止にまで踏み込んだ米朝会談は、トランプによる金正恩への一方的譲歩であり、後ろ盾だった中国の習近平も「勝ち組」になったかに見える。

その判断は…

［有料会員限定］ この記事は会員限定です。電子版に登録すると続きをお読みいただけます。

無料・有料プランを選択

今すぐ登録

会員の方はこちら

ログイン

電子版トップ

### 関連キーワード

- 北朝鮮政府中朝関係米国政府習近平金正恩温家宝トランプ蔡英文李克強父の日マリーナベイ・サンズ米朝ホットライン開設中国ワシントン中国国際航空

- #### [FT]米朝首脳会談、クシュナー氏が橋渡し （2018/6/18 14:10） ［有料会員限定］

- #### 金正恩氏が習近平氏に書簡　朝鮮中央通信 （2018/6/16 10:20）

- #### 米、北朝鮮非核化まで制裁継続 （2018/6/15付） ［有料会員限定］

## [PR]トレンドウオッチ

一覧

- 日経平均(円)
  6/19 大引
- 22,278.48
- -401.85
- -1.77%

- NYダウ(ドル)
  6/19 11:06
- 24,650.14
- -337.33
- -1.34%

- 日経アジア300
  6/19 終値
- 1,342.54
- -32.61
- -2.37%

- ドル(円)
  6/20 0:16
- 109.85-86
- -0.62円高
- -0.56%

- ユーロ(円)
  6/20 0:16
- 127.06-10
- -0.78円高
- -0.61%

- 長期金利(％)
  6/19 16:56
- 0.030
- ±0.000

- NY原油(ドル)
  6/19 11:11
- 64.72
- -1.13
- -1.71%

日経平均について （銘柄一覧）
QUICK
日経からのお知らせ

キャリア採用　記者募集

日経電子版をもっと知りたい方はこちら

日経産業新聞をデジタルで読みませんか？

## おすすめ情報

- 奥が深い新宿グルメ　次回はぜひここへ
- 「AIが仕事を奪う」はウソかもしれない
- 理想の転職できる人の5つの資質とは
- 5分で診断、あなたの市場価値
- 効率的にお腹を凹ませるトレーニング
- 南の島にセカンドハウス　今すぐ検索
- 接待当日　事前にしておくべきこと
- パワハラ防止へ組織が考えること

## [PR]

一覧はこちら

## アクセスランキング 一覧

- 1. 中国Ｍ＆Ａ阻止の動き　米欧政府、技術流出を警戒［有料会員限定］
- 2. 仮想通貨、ビットフライヤーなどに改善命令へ　金融庁［有料会員限定］
- 3. ロシア発　サッカーＷ杯ビジュアルブログ
- 4. 東証大引け　大幅続落、401円安　米中摩擦を警戒、中国株安も重荷
- 5. メルカリ山田会長「モデルはアマゾン」［有料会員限定］
- 6. 上場メルカリ、次の照準は米国　初日終値5300円［有料会員限定］
- 7. トランプ氏、対中制裁関税22兆円追加指示［有料会員限定］
- 8. 日産・ルノー、揺らぐ「暗黙の了解」（ルポ迫真）［有料会員限定］
- 9. 富士フイルム、ゼロックスを提訴［有料会員限定］
- 10. メルカリ上場、初値5000円［有料会員限定］

6/20 0:00 更新

##

### 日経 xTECH（クロステック）

#### IT業界内での知名度を売り物にするエンジニアたち

### 日経クロストレンド

#### ディープラーニングはヒット曲を作れるか

##

### 「スジ」の日本、「量」の中国

#### 「法律違反だが犯罪ではない」が成立する中国

### トレンド・ボックス

#### 酒を断つには、人間関係もリセットするしかない

##

### MONO TRENDY

#### 代表ユニホーム　ジャパンブルーは藍染めの青だった

### 出世ナビ　リーダーの母校

#### クジラ研究で鍛えた交渉力　凄腕コンサルの筑波大時代

### ヘルスＵＰ

#### 片足立ち、階段…　毎日やれば筋トレになる4つの習慣

### グルメクラブ　World Food Watch

#### 韓国式お好み焼き、チヂミはなぜ雨の日に食べる？

##

### 東大卒棋士のＡＩ勝負脳

#### 15歳の「藤井聡太」はなぜ将棋に勝てるのか

### 危機管理広報　エイレックス江良俊郎社長に聞く

#### 謝罪会見「絶対ダメ」なあの言葉

##

### ハーバードと日本の架け橋

#### 茶の世界を共有

### ホンネの就活ツッコミ論

#### Ｗ内定をどうする？

##

### ウーマノミクス・ストーリー

#### 英語使える日本人を少しでも、長年の課題に新プログラムで挑む（ECC）

##

### PICK UP

#### 人も仕事も多様性を追求、イノベーション創り出す丸紅へ

##

### 予定調和を壊す生放送への思い

#### 青春高校３年Ｃ組～秋元康インタビュー (無料)

### こだわる男は、かっこいい

#### 俺のダンディズム（テレビ東京ドラマ）

## 日経のイベント・セミナー

- 生誕150年　横山大観展 6月8日～7月22日 京都国立近代美術館
- 日経TEST「企業・団体試験」 ご希望の日時と場所で実施できます

天気 プレスリリース検索

アカウント一覧

訂正・おわび

## 日本経済新聞社の関連サイト

## 日経ＩＤの関連サイト

## 日本経済新聞 関連情報

### イベント・セミナー

- 日経イベンツガイド
- 日経ホールと貸会議室
- 日経懇話会
- 講演会向け講師紹介

### 教育・キャリア

- Versant
- 日経の研修とは
- 日経TEST
- 日経キャリアNET 転職

### 各種サービス

- 日経テレコン
- N-BRAND STUDIO
- ＮＥＥＤＳ
- 日本経済新聞の本
- Channel JAPAN
- 日経グローカル
- NIKKEI CHANNEL

## 日本経済新聞 電子版について

- サイトポリシー
- ヘルプセンター
- FAQ・お問い合わせ
- ご購読サポート
- Web広告ガイド
- リンクポリシー
- 著作権
- データ利用
- 個人情報
- 利用規約
- サイトマップ

## 日本経済新聞社について

- 会社情報・お知らせ
- 記事利用
- 個人情報の取り扱い
- 本社採用案内
- 日経グループ情報
- 新聞広告お申し込みガイド
- 紙面紹介と購読案内
- 法人お問い合わせ窓口

Nikkei Inc. No reproduction without permission.